Struct Lpcr
#[repr(transparent)]pub struct Lpcr(pub u32);Expand description
DSI Host LTDC polarity configuration register.
Tuple Fields
0: u32Implementations
impl Lpcr
impl Lpcr
pub const fn dep(&self) -> bool
pub const fn dep(&self) -> bool
Data enable polarity This bit configures the polarity of data enable pin.
pub const fn set_dep(&mut self, val: bool)
pub const fn set_dep(&mut self, val: bool)
Data enable polarity This bit configures the polarity of data enable pin.